@@ -3,8 +3,10 @@ use warnings;
 use strict;
 use base 'Text::Microformat::Element';
 
-__PACKAGE__->_init(
-	'hgrant',
+__PACKAGE__->_init({
+    criteria => {
+        class => 'hgrant',
+    },
 	schema => {
 		title => [],
 	    period => [qw/dtstart dtend/],
@@ -14,8 +16,13 @@ __PACKAGE__->_init(
 	    amount => [qw/currency amount/],
 	    url => 'URI',
 		id => [],
+		'geo-focus' => [qw/country region locality postal-code/],
+		'program-focus' => {
+		    tags => '!rel-tag',
+		},
+		tags => '!rel-tag',
 	},
-);
+});
 
 =head1 NAME
 
